/************************************************************************
 *
 * Copyright (C) 2025 IRCAD France
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#pragma once

#include <cppunit/extensions/HelperMacros.h>

namespace sight::data::validator::ut
{

/// Test the stereo_camera validator
class filled_test : public CPPUNIT_NS::TestFixture
{
CPPUNIT_TEST_SUITE(filled_test);
CPPUNIT_TEST(image);
CPPUNIT_TEST(model_series);
CPPUNIT_TEST(point_list);
CPPUNIT_TEST(string_serializable);
CPPUNIT_TEST_SUITE_END();

public:

    // interface
    void setUp() override;
    void tearDown() override;

    static void image();
    static void model_series();
    static void point_list();
    static void string_serializable();
};

} // namespace sight::data::validator::ut
